/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface EventarcMessageBusConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. Resource annotations.
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#annotations EventarcMessageBus#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Optional. Resource name of a KMS crypto key (managed by the user) used to
    * encrypt/decrypt their event data.
    *
    * It must match the pattern
    * 'projects/* /locations/* /keyRings/* /cryptoKeys/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#crypto_key_name EventarcMessageBus#crypto_key_name}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly cryptoKeyName?: string;
    /**
    * Optional. Resource display name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#display_name EventarcMessageBus#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#id EventarcMessageBus#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Optional. Resource labels.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#labels EventarcMessageBus#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#location EventarcMessageBus#location}
    */
    readonly location: string;
    /**
    * Required. The user-provided ID to be assigned to the MessageBus. It should match the
    * format '^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#message_bus_id EventarcMessageBus#message_bus_id}
    */
    readonly messageBusId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#project EventarcMessageBus#project}
    */
    readonly project?: string;
    /**
    * logging_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#logging_config EventarcMessageBus#logging_config}
    */
    readonly loggingConfig?: EventarcMessageBusLoggingConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#timeouts EventarcMessageBus#timeouts}
    */
    readonly timeouts?: EventarcMessageBusTimeouts;
}
export interface EventarcMessageBusLoggingConfig {
    /**
    * Optional. The minimum severity of logs that will be sent to Stackdriver/Platform
    * Telemetry. Logs at severitiy ≥ this value will be sent, unless it is NONE. Possible values: ["NONE", "DEBUG", "INFO", "NOTICE", "WARNING", "ERROR", "CRITICAL", "ALERT", "EMERGENCY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#log_severity EventarcMessageBus#log_severity}
    */
    readonly logSeverity?: string;
}
export declare function eventarcMessageBusLoggingConfigToTerraform(struct?: EventarcMessageBusLoggingConfigOutputReference | EventarcMessageBusLoggingConfig): any;
export declare function eventarcMessageBusLoggingConfigToHclTerraform(struct?: EventarcMessageBusLoggingConfigOutputReference | EventarcMessageBusLoggingConfig): any;
export declare class EventarcMessageBusLoggingConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): EventarcMessageBusLoggingConfig | undefined;
    set internalValue(value: EventarcMessageBusLoggingConfig | undefined);
    private _logSeverity?;
    get logSeverity(): string;
    set logSeverity(value: string);
    resetLogSeverity(): void;
    get logSeverityInput(): string | undefined;
}
export interface EventarcMessageBusTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#create EventarcMessageBus#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#delete EventarcMessageBus#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#update EventarcMessageBus#update}
    */
    readonly update?: string;
}
export declare function eventarcMessageBusTimeoutsToTerraform(struct?: EventarcMessageBusTimeouts | cdktf.IResolvable): any;
export declare function eventarcMessageBusTimeoutsToHclTerraform(struct?: EventarcMessageBusTimeouts | cdktf.IResolvable): any;
export declare class EventarcMessageBusTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): EventarcMessageBusTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: EventarcMessageBusTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus google_eventarc_message_bus}
*/
export declare class EventarcMessageBus extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_eventarc_message_bus";
    /**
    * Generates CDKTF code for importing a EventarcMessageBus resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the EventarcMessageBus to import
    * @param importFromId The id of the existing EventarcMessageBus that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the EventarcMessageBus to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/eventarc_message_bus google_eventarc_message_bus} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options EventarcMessageBusConfig
    */
    constructor(scope: Construct, id: string, config: EventarcMessageBusConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get createTime(): string;
    private _cryptoKeyName?;
    get cryptoKeyName(): string;
    set cryptoKeyName(value: string);
    resetCryptoKeyName(): void;
    get cryptoKeyNameInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _messageBusId?;
    get messageBusId(): string;
    set messageBusId(value: string);
    get messageBusIdInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _loggingConfig;
    get loggingConfig(): EventarcMessageBusLoggingConfigOutputReference;
    putLoggingConfig(value: EventarcMessageBusLoggingConfig): void;
    resetLoggingConfig(): void;
    get loggingConfigInput(): EventarcMessageBusLoggingConfig | undefined;
    private _timeouts;
    get timeouts(): EventarcMessageBusTimeoutsOutputReference;
    putTimeouts(value: EventarcMessageBusTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | EventarcMessageBusTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
