/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IamOauthClientCredentialConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether the OauthClientCredential is disabled. You cannot use a
    * disabled OauthClientCredential.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential#disabled IamOauthClientCredential#disabled}
    */
    readonly disabled?: boolean | cdktf.IResolvable;
    /**
    * A user-specified display name of the OauthClientCredential.
    *
    * Cannot exceed 32 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential#display_name IamOauthClientCredential#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential#id IamOauthClientCredential#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential#location IamOauthClientCredential#location}
    */
    readonly location: string;
    /**
    * Required. The ID to use for the OauthClientCredential, which becomes the
    * final component of the resource name. This value should be 4-32 characters,
    * and may contain the characters [a-z0-9-]. The prefix 'gcp-' is
    * reserved for use by Google, and may not be specified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential#oauth_client_credential_id IamOauthClientCredential#oauth_client_credential_id}
    */
    readonly oauthClientCredentialId: string;
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential#oauthclient IamOauthClientCredential#oauthclient}
    */
    readonly oauthclient: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential#project IamOauthClientCredential#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential#timeouts IamOauthClientCredential#timeouts}
    */
    readonly timeouts?: IamOauthClientCredentialTimeouts;
}
export interface IamOauthClientCredentialTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential#create IamOauthClientCredential#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential#delete IamOauthClientCredential#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential#update IamOauthClientCredential#update}
    */
    readonly update?: string;
}
export declare function iamOauthClientCredentialTimeoutsToTerraform(struct?: IamOauthClientCredentialTimeouts | cdktf.IResolvable): any;
export declare function iamOauthClientCredentialTimeoutsToHclTerraform(struct?: IamOauthClientCredentialTimeouts | cdktf.IResolvable): any;
export declare class IamOauthClientCredentialTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IamOauthClientCredentialTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: IamOauthClientCredentialTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential google_iam_oauth_client_credential}
*/
export declare class IamOauthClientCredential extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_iam_oauth_client_credential";
    /**
    * Generates CDKTF code for importing a IamOauthClientCredential resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the IamOauthClientCredential to import
    * @param importFromId The id of the existing IamOauthClientCredential that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the IamOauthClientCredential to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/iam_oauth_client_credential google_iam_oauth_client_credential} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IamOauthClientCredentialConfig
    */
    constructor(scope: Construct, id: string, config: IamOauthClientCredentialConfig);
    get clientSecret(): string;
    private _disabled?;
    get disabled(): boolean | cdktf.IResolvable;
    set disabled(value: boolean | cdktf.IResolvable);
    resetDisabled(): void;
    get disabledInput(): boolean | cdktf.IResolvable | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _oauthClientCredentialId?;
    get oauthClientCredentialId(): string;
    set oauthClientCredentialId(value: string);
    get oauthClientCredentialIdInput(): string | undefined;
    private _oauthclient?;
    get oauthclient(): string;
    set oauthclient(value: string);
    get oauthclientInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _timeouts;
    get timeouts(): IamOauthClientCredentialTimeoutsOutputReference;
    putTimeouts(value: IamOauthClientCredentialTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | IamOauthClientCredentialTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
