/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworkSecurityMirroringEndpointGroupAssociationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association#id NetworkSecurityMirroringEndpointGroupAssociation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Labels are key/value pairs that help to organize and filter resources.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association#labels NetworkSecurityMirroringEndpointGroupAssociation#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The cloud location of the association, currently restricted to 'global'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association#location NetworkSecurityMirroringEndpointGroupAssociation#location}
    */
    readonly location: string;
    /**
    * The endpoint group that this association is connected to, for example:
    * 'projects/123456789/locations/global/mirroringEndpointGroups/my-eg'.
    * See https://google.aip.dev/124.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association#mirroring_endpoint_group NetworkSecurityMirroringEndpointGroupAssociation#mirroring_endpoint_group}
    */
    readonly mirroringEndpointGroup: string;
    /**
    * The ID to use for the new association, which will become the final
    * component of the endpoint group's resource name. If not provided, the
    * server will generate a unique ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association#mirroring_endpoint_group_association_id NetworkSecurityMirroringEndpointGroupAssociation#mirroring_endpoint_group_association_id}
    */
    readonly mirroringEndpointGroupAssociationId?: string;
    /**
    * The VPC network that is associated. for example:
    * 'projects/123456789/global/networks/my-network'.
    * See https://google.aip.dev/124.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association#network NetworkSecurityMirroringEndpointGroupAssociation#network}
    */
    readonly network: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association#project NetworkSecurityMirroringEndpointGroupAssociation#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association#timeouts NetworkSecurityMirroringEndpointGroupAssociation#timeouts}
    */
    readonly timeouts?: NetworkSecurityMirroringEndpointGroupAssociationTimeouts;
}
export interface NetworkSecurityMirroringEndpointGroupAssociationLocationsDetails {
}
export declare function networkSecurityMirroringEndpointGroupAssociationLocationsDetailsToTerraform(struct?: NetworkSecurityMirroringEndpointGroupAssociationLocationsDetails): any;
export declare function networkSecurityMirroringEndpointGroupAssociationLocationsDetailsToHclTerraform(struct?: NetworkSecurityMirroringEndpointGroupAssociationLocationsDetails): any;
export declare class NetworkSecurityMirroringEndpointGroupAssociationLocationsDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkSecurityMirroringEndpointGroupAssociationLocationsDetails | undefined;
    set internalValue(value: NetworkSecurityMirroringEndpointGroupAssociationLocationsDetails | undefined);
    get location(): string;
    get state(): string;
}
export declare class NetworkSecurityMirroringEndpointGroupAssociationLocationsDetailsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkSecurityMirroringEndpointGroupAssociationLocationsDetailsOutputReference;
}
export interface NetworkSecurityMirroringEndpointGroupAssociationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association#create NetworkSecurityMirroringEndpointGroupAssociation#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association#delete NetworkSecurityMirroringEndpointGroupAssociation#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association#update NetworkSecurityMirroringEndpointGroupAssociation#update}
    */
    readonly update?: string;
}
export declare function networkSecurityMirroringEndpointGroupAssociationTimeoutsToTerraform(struct?: NetworkSecurityMirroringEndpointGroupAssociationTimeouts | cdktf.IResolvable): any;
export declare function networkSecurityMirroringEndpointGroupAssociationTimeoutsToHclTerraform(struct?: NetworkSecurityMirroringEndpointGroupAssociationTimeouts | cdktf.IResolvable): any;
export declare class NetworkSecurityMirroringEndpointGroupAssociationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkSecurityMirroringEndpointGroupAssociationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkSecurityMirroringEndpointGroupAssociationTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association google_network_security_mirroring_endpoint_group_association}
*/
export declare class NetworkSecurityMirroringEndpointGroupAssociation extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_security_mirroring_endpoint_group_association";
    /**
    * Generates CDKTF code for importing a NetworkSecurityMirroringEndpointGroupAssociation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetworkSecurityMirroringEndpointGroupAssociation to import
    * @param importFromId The id of the existing NetworkSecurityMirroringEndpointGroupAssociation that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetworkSecurityMirroringEndpointGroupAssociation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/network_security_mirroring_endpoint_group_association google_network_security_mirroring_endpoint_group_association} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetworkSecurityMirroringEndpointGroupAssociationConfig
    */
    constructor(scope: Construct, id: string, config: NetworkSecurityMirroringEndpointGroupAssociationConfig);
    get createTime(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _locationsDetails;
    get locationsDetails(): NetworkSecurityMirroringEndpointGroupAssociationLocationsDetailsList;
    private _mirroringEndpointGroup?;
    get mirroringEndpointGroup(): string;
    set mirroringEndpointGroup(value: string);
    get mirroringEndpointGroupInput(): string | undefined;
    private _mirroringEndpointGroupAssociationId?;
    get mirroringEndpointGroupAssociationId(): string;
    set mirroringEndpointGroupAssociationId(value: string);
    resetMirroringEndpointGroupAssociationId(): void;
    get mirroringEndpointGroupAssociationIdInput(): string | undefined;
    get name(): string;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): NetworkSecurityMirroringEndpointGroupAssociationTimeoutsOutputReference;
    putTimeouts(value: NetworkSecurityMirroringEndpointGroupAssociationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | NetworkSecurityMirroringEndpointGroupAssociationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
