/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface StorageAnywhereCacheConfig extends cdktf.TerraformMetaArguments {
    /**
    * The cache admission policy dictates whether a block should be inserted upon a cache miss. Default value: "admit-on-first-miss" Possible values: ["admit-on-first-miss", "admit-on-second-miss"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/storage_anywhere_cache#admission_policy StorageAnywhereCache#admission_policy}
    */
    readonly admissionPolicy?: string;
    /**
    * A reference to Bucket resource
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/storage_anywhere_cache#bucket StorageAnywhereCache#bucket}
    */
    readonly bucket: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/storage_anywhere_cache#id StorageAnywhereCache#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The TTL of all cache entries in whole seconds. e.g., "7200s". It defaults to '86400s'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/storage_anywhere_cache#ttl StorageAnywhereCache#ttl}
    */
    readonly ttl?: string;
    /**
    * The zone in which the cache instance needs to be created. For example, 'us-central1-a.'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/storage_anywhere_cache#zone StorageAnywhereCache#zone}
    */
    readonly zone: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/storage_anywhere_cache#timeouts StorageAnywhereCache#timeouts}
    */
    readonly timeouts?: StorageAnywhereCacheTimeouts;
}
export interface StorageAnywhereCacheTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/storage_anywhere_cache#create StorageAnywhereCache#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/storage_anywhere_cache#delete StorageAnywhereCache#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/storage_anywhere_cache#update StorageAnywhereCache#update}
    */
    readonly update?: string;
}
export declare function storageAnywhereCacheTimeoutsToTerraform(struct?: StorageAnywhereCacheTimeouts | cdktf.IResolvable): any;
export declare function storageAnywhereCacheTimeoutsToHclTerraform(struct?: StorageAnywhereCacheTimeouts | cdktf.IResolvable): any;
export declare class StorageAnywhereCacheTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): StorageAnywhereCacheTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: StorageAnywhereCacheTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/storage_anywhere_cache google_storage_anywhere_cache}
*/
export declare class StorageAnywhereCache extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_storage_anywhere_cache";
    /**
    * Generates CDKTF code for importing a StorageAnywhereCache resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the StorageAnywhereCache to import
    * @param importFromId The id of the existing StorageAnywhereCache that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/storage_anywhere_cache#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the StorageAnywhereCache to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.26.0/docs/resources/storage_anywhere_cache google_storage_anywhere_cache} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options StorageAnywhereCacheConfig
    */
    constructor(scope: Construct, id: string, config: StorageAnywhereCacheConfig);
    private _admissionPolicy?;
    get admissionPolicy(): string;
    set admissionPolicy(value: string);
    resetAdmissionPolicy(): void;
    get admissionPolicyInput(): string | undefined;
    get anywhereCacheId(): string;
    private _bucket?;
    get bucket(): string;
    set bucket(value: string);
    get bucketInput(): string | undefined;
    get createTime(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get pendingUpdate(): cdktf.IResolvable;
    get state(): string;
    private _ttl?;
    get ttl(): string;
    set ttl(value: string);
    resetTtl(): void;
    get ttlInput(): string | undefined;
    get updateTime(): string;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    get zoneInput(): string | undefined;
    private _timeouts;
    get timeouts(): StorageAnywhereCacheTimeoutsOutputReference;
    putTimeouts(value: StorageAnywhereCacheTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | StorageAnywhereCacheTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
